@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 CanDo view components.
@@ -1003,6 +1002,7 @@ class AggregateNodesTableFilter(schooltool.table.ajax.IndexedTableFilter):
                 found_in_catalog = index.apply(query)
             else:
                 found_in_catalog = tuple(catalog.extent)
+            found_in_catalog = self.removeRetired(catalog, found_in_catalog)
             found_ids.update(found_in_catalog)
             request_layer_ids.remove(self.skill_layer_id)
 
@@ -1013,6 +1013,7 @@ class AggregateNodesTableFilter(schooltool.table.ajax.IndexedTableFilter):
                 found_in_catalog = index.apply(query)
             else:
                 found_in_catalog = tuple(catalog.extent)
+            found_in_catalog = self.removeRetired(catalog, found_in_catalog)
             found_ids.update(found_in_catalog)
             request_layer_ids.remove(self.skillset_layer_id)
 
@@ -1022,6 +1023,7 @@ class AggregateNodesTableFilter(schooltool.table.ajax.IndexedTableFilter):
             found_in_catalog = set(index.apply(query))
         else:
             found_in_catalog = set(catalog.extent)
+        found_in_catalog = self.removeRetired(catalog, found_in_catalog)
         index = getNodeCatalog()['layers']
         if self.no_layer_id in request_layer_ids:
             found_no_layers = set(catalog.extent).difference(index.ids())
@@ -1036,6 +1038,12 @@ class AggregateNodesTableFilter(schooltool.table.ajax.IndexedTableFilter):
         result = filter(lambda i: i['id'] in found_ids, items)
         return result
 
+    def removeRetired(self, catalog, found_ids):
+        retired = set()
+        index = catalog['retired']
+        retired = index.values_to_documents.get(True, set())
+        return set(found_ids).difference(retired)
+
 
 class AggregateNodesSkillsSearchTable(table.ajax.IndexedTable):
 
