@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """CanDo Gradebook."""
 
@@ -272,9 +271,9 @@ class CanDoStudentGradebook(StudentGradebook):
     implements(ICanDoStudentGradebook)
     adapts(IBasicPerson, ICanDoGradebook)
 
-    def __init__(self, *args, **kw):
-        super(CanDoStudentGradebook, self).__init__(*args, **kw)
-        self.__parent__ = self.gradebook.__parent__
+    @property
+    def __parent__(self):
+        return self.gradebook.__parent__
 
 
 class CanDoStudentGradebookTraverser(object):
