@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """Skills document model."""
 import itertools
@@ -167,15 +166,17 @@ class Node(Persistent, Contained):
     title = u''
     description = u''
     label = u''
+    retired = False
     layers = RelationshipProperty(URINodeLayer, URINode, URILayer)
     parents = RelationshipProperty(URINodeLink, URINode, URIParentNode)
     children = RelationshipProperty(URINodeLink, URIParentNode, URINode)
     skillsets = RelationshipProperty(URINodeSkillSets, URINode, URISkillSet)
 
-    def __init__(self, title=u'', description=u'', label=u''):
+    def __init__(self, title=u'', description=u'', label=u'', retired=False):
         self.title = title
         self.description = description
         self.label = label
+        self.retired = retired
 
     def findPaths(self):
         paths = [(self,)]
